EdDicomModel class
Constructors
-
EdDicomModel({required List<
int> decodedBytes, required String patientName, required String patientGender, required String patientID, required String patientAge, required String patientBirthDate, required String patientWeight, required String patientHeight}) -
EdDicomModel.fromJson(Map<
String, dynamic> json) -
factory
Properties
-
decodedBytes
→ List<
int> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- patientAge → String
-
final
- patientBirthDate → String
-
final
- patientGender → String
-
final
- patientHeight → String
-
final
- patientID → String
-
final
- patientName → String
-
final
- patientWeight → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited